import {model, ObjectId, Schema} from "mongoose";
import { fieldEncryption } from "mongoose-field-encryption";
import process from "process";

export interface IGroup {
    projectId: ObjectId,
    name: string,
    description?: string,
    permissions: string[]
}

const GroupSchema = new Schema<IGroup>({
    projectId: {
        type: String,
        required: true
    },
    name: {
        type: String,
        required: true
    },
    description: {
        type: String,
        default: "Keine Beschreibung angegeben"
    },
    permissions: [String]
});

GroupSchema.plugin(fieldEncryption, {
    fields: ["projectId", "name", "description", "permissions"],
    secret: process.env.ENC_KEY,
    saltGenerator: () => process.env.SIG_KEY
});

export const Group = model<IGroup>("groups", GroupSchema);