import { model, Schema } from "mongoose";
import { fieldEncryption } from "mongoose-field-encryption";

export enum ILicenseMetaType {
    TEXT = "TEXT",
    NUMBER = "NUMBER",
    BOOLEAN = "BOOLEAN"
}

export interface IMetaData {
    projectId: string,
    type: ILicenseMetaType,
    name: string,
    description?: string,
    defaultValue?: string,
    public: boolean
}

const MetaDataSchema = new Schema<IMetaData>({
    projectId: {
        type: String,
        required: true
    },
    type: {
        type: String,
        required: true
    },
    name: {
        type: String,
        required: true
    },
    description: {
        type: String,
        required: true
    },
    defaultValue: String,
    public: {
        type: Boolean,
        default: false
    }
});

MetaDataSchema.plugin(fieldEncryption, {
    fields: ["projectId", "type", "name", "description", "defaultValue"],
    secret: process.env.ENC_KEY,
    saltGenerator: () => process.env.SIG_KEY,
});

export const MetaData = model<IMetaData>("meta", MetaDataSchema);