import {model, ObjectId, Schema} from "mongoose";
import { fieldEncryption } from "mongoose-field-encryption";
import process from "process";

export interface IPermission {
    projectId: ObjectId,
    permission: string,
    description: string
}

const PermissionSchema = new Schema<IPermission>({
    projectId: {
        type: String,
        required: true
    },
    permission: {
        type: String,
        required: true
    },
    description: {
        type: String,
        default: "Keine Beschreibung angegeben"
    }
});

PermissionSchema.plugin(fieldEncryption, {
    fields: ["projectId", "permission", "description"],
    secret: process.env.ENC_KEY,
    saltGenerator: () => process.env.SIG_KEY
});

export const Permission = model<IPermission>("permissions", PermissionSchema);